@@ -2,7 +2,7 @@
    Copyright 1996, 1997 Linux International.
 
    New implementation contributed by Richard Henderson <rth@tamu.edu>
-   Based on original work by Bjorn Eckwall <bj0rn@blox.se>
+   Based on original work by Bjorn Ekwall <bj0rn@blox.se>
 
    This file is part of the Linux modutils.
 
@@ -24,8 +24,6 @@
 #ifndef MODUTILS_GENKSYMS_H
 #define MODUTILS_GENKSYMS_H 1
 
-#ident "$Id: genksyms.h,v 1.1 1997/09/10 22:11:13 rth Exp $"
-
 #include <stdio.h>
 
 enum symbol_type
@@ -47,6 +45,7 @@ struct symbol
   enum symbol_type type;
   struct string_list *defn;
   struct symbol *expansion_trail;
+  int is_extern;
 };
 
 typedef struct string_list **yystype;
@@ -57,7 +56,7 @@ extern FILE *outfile, *debugfile;
 extern int cur_line;
 extern char *cur_filename, *output_directory;
 
-extern int flag_debug, flag_dump_defs, flag_export_globals, flag_warnings;
+extern int flag_debug, flag_dump_defs, flag_warnings;
 extern int checksum_version, kernel_version;
 
 extern int want_brace_phrase, want_exp_phrase, discard_phrase_contents;
@@ -66,7 +65,7 @@ extern struct string_list *current_list, *next_list;
 
 struct symbol *find_symbol(const char *name, enum symbol_type ns);
 struct symbol *add_symbol(const char *name, enum symbol_type type,
-			   struct string_list *defn);
+			   struct string_list *defn, int is_extern);
 void export_symbol(const char *);
 
 struct string_list *reset_list(void);
